@@ -6,15 +6,25 @@ class ContextBase:
     def __init__(self):
         self._types = {}  # 模型类型映射，用于校验list，dict或者默认为None的数据的配置类型是否争取
 
-    def load(self, json):
+    def load(self, json, force_set_value = False):
+        """
+        装载json数据到当前对象中
+        :param json:
+        :param force_set_value: 在校验不通过的时候，强制设置值。比如Parameter的默认值为None，但是在json中没有配置，也需要设置为None
+        :return:
+        """
         if not isinstance(json, dict):
             raise Exception(f'装载对象需要是一个字典。 {self.__class__}')
         for k, v in json.items():
-            if v is None:
+            if v is None and not force_set_value:
+                # 针对param的默认值，做了特殊处理，需要强行设值
                 continue
+
             if hasattr(self, k) and isinstance(getattr(self, k), ContextBase):
                 # 已经初始了Base类型的对象，直接使用对象进行装载
                 getattr(self, k).load(v)
+            elif hasattr(self, k) and isinstance(getattr(self, k), dict) and self._types.get(k) == dict:
+                setattr(self, k, v)
             elif hasattr(self, k) and isinstance(getattr(self, k), dict):
                 # 已经初始化了dict类型的对象，根据字典的类型定义进行装载
                 if not isinstance(v, dict):
@@ -59,7 +69,7 @@ class ContextBase:
                     raise Exception(f'{v} 和需要的类型不一致。 {type(instance).__name__}')
             elif hasattr(self, k) and type(v).__name__ == type(getattr(self, k)).__name__:
                 setattr(self, k, v)
-            elif hasattr(self, 'type') and (type(v).__name__ == getattr(self, 'type') or v is None):
+            elif force_set_value:       # 强行设值
                 setattr(self, k, v)
             elif hasattr(self, k) and type(v).__name__ != type(getattr(self, k)).__name__:
                 raise Exception(f'{k} 和需要的类型不一致。 需要的类型{type(getattr(self, k)).__name__}，指定是{type(v).__name__}')
