@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from fastcodedog.context.context import ctx_instance
+from fastcodedog.generation.api.config import Config
 from fastcodedog.generation.api.db import Db
 from fastcodedog.generation.base.file import File
 from fastcodedog.generation.base.function import Function
@@ -67,8 +68,8 @@ OAuth2.REDIS_URL = 'redis://localhost:6379/oauth2'""")
             possible_imports=Import(model_name, LocationFinder.get_package(model_name, 'model', module))
         ))
         function.blocks.append(Text(f"""if {snake_name}:
-    return OAuth2.create_access_token({{"{primary_key_name}": {snake_name}.{primary_key_name}, "{user_name_column_name}": username}})""",
-                                    possible_imports='from fastoauth import OAuth2'))
+    return OAuth2.create_access_token({{"{primary_key_name}": {snake_name}.{primary_key_name}, "{user_name_column_name}": username}}, expire_seconds=oauth2_expire_seconds)""",
+                                    possible_imports=['from fastoauth import OAuth2', Import('oauth2_expire_seconds', Config().package)]))
         function.blocks.append(
             Text("""raise HTTPException(status_code=HTTP_401_UNAUTHORIZED, detail="Incorrect username or password")""",
                  possible_imports=['from fastapi import HTTPException',
